{
  description = "https://blood.pet";

  inputs = {
    nixpkgs.url = "github:NixOS/nixpkgs/nixos-unstable";
    flake-utils.url = "github:numtide/flake-utils";
    teapot.url = "git+https://git.sapphic.engineer/noe/teapot";
    mermaid-ascii.url = "github:AlexanderGrooff/mermaid-ascii";
  };

  outputs = { self, nixpkgs, flake-utils, ... }@inputs: flake-utils.lib.eachDefaultSystem (
    system: let 
      pkgs = import nixpkgs {
        inherit system;
        overlays = [
          inputs.teapot.overlays.default
          (final: prev: {
            mermaid-ascii = inputs.mermaid-ascii.packages.${system}.default;
          })
        ];
      };
    in {
      devShells.default = import ./shell.nix { inherit pkgs; };

      packages.default = pkgs.brewTea {
        name = "blood.pet";
        version = "0.0.0";
        
        src = ./.;
        layoutSrc = ./layouts;
        staticAssets = [ "./static" ];

        markdollPlugins = [
          (pkgs.mkMarkdollPlugin "utils" ./plugins/utils.sh)
          (pkgs.mkMarkdollPlugin "logroll" ./plugins/logroll.sh)
          (pkgs.mkMarkdollPlugin "dollcode" ./plugins/dollcode.sh)

          (pkgs.mkMarkdollPlugin "mermaid" ./plugins/mermaid.sh)
          pkgs.mermaid-ascii
        ];
      };
    }
  );
}